Image Moments {#tutorial_moments}
=============

Goal
----

In this tutorial you will learn how to:

-   Use the OpenCV function @ref cv::moments
-   Use the OpenCV function @ref cv::contourArea
-   Use the OpenCV function @ref cv::arcLength

Theory
------

Code
----

This tutorial code's is shown lines below. You can also download it from
[here](https://github.com/opencv/opencv/tree/master/samples/cpp/tutorial_code/ShapeDescriptors/moments_demo.cpp)
@include samples/cpp/tutorial_code/ShapeDescriptors/moments_demo.cpp

Explanation
-----------

Result
------

Here it is:
![](images/Moments_Source_Image.jpg)
![](images/Moments_Result1.jpg)
![](images/Moments_Result2.jpg)
